import { Extractor } from './interfaces/Extractor';
import { GeneralTransformer } from './interfaces/GeneralTransformer';
import { Transformer } from './interfaces/Transformer';
import { Loader } from './interfaces/Loader';
import { Observable } from 'rxjs';
export declare enum EtlState {
    Running = 0,
    Stopped = 1,
    Error = 2,
}
/**
 * ETL Class. Instantiate one and add as many extractors, transformers and loaders as you want.
 * Then start the whole process with ".start()".
 *
 * This processor is modular, you can find other implemented loaders and extractors in the README
 */
export declare class Etl {
    private _extractors;
    private _generalTransformers;
    private _transformers;
    private _loaders;
    private _state;
    extractors: Extractor[];
    generalTransformers: GeneralTransformer[];
    transformers: Transformer[];
    loaders: Loader[];
    state: EtlState;
    addExtractor(extract: Extractor): Etl;
    addGeneralTransformer(transformer: GeneralTransformer): Etl;
    addTransformer(transformer: Transformer): Etl;
    addLoader(loader: Loader): Etl;
    /**
     * Starts the etl process. First, all extractors are run in parallel and deliver their results into an observable.
     * Once the buffer gets a result, it transfers all objects through the transformers (one by one).
     * After that, the transformed results are run through all loaders in parallel.
     *
     * @returns {Observable<any>} Observable that completes when the process is finished,
     *                            during the "next" process step you get update on how many are processed yet.
     *                            Throws when any step produces an error.
     */
    start(): Observable<any>;
    /**
     * Resets the whole Etl object. Deletes all modifiers and resets the state.
     */
    reset(): void;
}
